<?xml version='1.0'?> 

<xsl:stylesheet version="1.0"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:xlink = "http://www.w3.org/1999/xlink"> 

 <xsl:variable name="ParaSymbol">&#182;</xsl:variable> 
 <xsl:variable name="RequiredSpaces"> 
 &#xa0;&#xa0;&#xa0;&#xa0;&#xa0;&#xa0;</xsl:variable> 
 <xsl:output method="html"/> 
 
 <!-- 
 ##################################################################### 
 --> 
 <!-- #USAGE - The root template sets out the HTML elements of 
the HTML page  into which the contents of the underlying XML document will be 
placed.	--> 
 
 <xsl:template match="/"> 
 
 <html> 
 <head> 
 
 <!-- 
 ********************************************************************* 
 --> 
 <!-- #USAGE - The following transforms the title of the document 
(i.e., the contents of the <documentTitle> element), into the title of the 
HTML age.  --> 
 
 <title><xsl:value-of select="legal/courtDocument//documentTitle"/>
</title> 
 
 </head> 
 
 <body style="font-family: CG Times; font-size:10pt; margin-left:10%; 
margin-top:0.5cm; margin-right:10%">

 <xsl:apply-templates select="legal//caseMetadata"/> 
  <xsl:apply-templates select="legal//documentBody"/> 
  <xsl:apply-templates select="legal//signers"/> 

<!-- This displays footnotes as endnotes to the document after the "signers" information. -->

	<xsl:for-each select="//footnote">
		<p/>
			<a>
				<xsl:attribute name="name">
					<xsl:value-of select="footnoteNumber"/>
				</xsl:attribute>
				<div style="font-size:10pt; font-weight:bold; display:inline; vertical-align:super">
					<xsl:value-of select="footnoteNumber"/>&#xa0;
				</div>
			</a>
		<xsl:value-of select="footnoteBody"/>
	</xsl:for-each>

 <xsl:apply-templates select="legal//proofOfService"/> 
 
 </body> 
 </html> 
 
 </xsl:template> 
 
 <xsl:template match="caseMetadata"> 
 
<a>
	<xsl:attribute name="href">
		<xsl:value-of select="../documentMetadata//link/@xlink:href"/>
	</xsl:attribute>
		<xsl:value-of select = "../documentMetadata//link/@xlink:title"/>
</a>

 <div align="center" style="font-weight:bold"> 
 In the <xsl:value-of select="court/courtName"/> <br/> 
 State of <xsl:value-of select="court//state"/> <br/>  
 <xsl:value-of select="court//courtDivision"/>
 <br></br> 
 </div> 
 
 <!-- ************************************************************ 
--> 
 
 <div style="margin-top:0.5cm; background-color:#FFFFFF; font-weight:bold"> 
 
 <!-- &#xa0; adds a whitespace. --> 
 
 <table width='100%' border='1' cellpadding='10'> 
 <tr> 
 <td width='50%'> 
<xsl:for-each select="caseTitle/party[@partyType='Appellee/Respondent' or @partyType='Appellee']"> 
 	<xsl:value-of select="organization/organizationName | person/fullName"/>,<P/> 
 	&#xa0;&#xa0;&#xa0;&#xa0;&#xa0;&#xa0;<xsl:value-of select="@partyType"/>, 
</xsl:for-each>

 <P/> 
 	<xsl:value-of select="caseTitle/vs"/> 
 <P/>

 <xsl:for-each select="caseTitle/party[@partyType='Appellant/Petitioner' or @partyType='Appellant']">
 	<xsl:value-of select="organization/organizationName | person/fullName"/>,<P/> 
 	&#xa0;&#xa0;&#xa0;&#xa0;&#xa0;&#xa0;<xsl:value-of select="@partyType"/>.<br/> 
 </xsl:for-each> 
 </td> 
 
 <td width="50%" align="left">
<div style="margin-left:1cm">
 <xsl:value-of select="fullCaseNumber"/> 
 <br/> 
 <xsl:for-each select="relatedCase">
  	<xsl:if test="contains(comment, 'Consolidated')">
	 	<xsl:value-of select="fullCaseNumber"/><br/> 
		(<xsl:value-of select="comment"/>)<br/> 
	</xsl:if>
 </xsl:for-each> 
<xsl:value-of select="..//courtDepartment"/>
 <br/><br/> 
 
 <u> 
  <xsl:value-of select="..//documentType"/>
 </u> 
 <br/> 
 </div>
 </td> 
 
 </tr> 
 
 </table> 
 
 </div> 
 <div align="center" style="font-weight:bold"> 
<p/>

<!-- Display <documentTitle> contents -->

<xsl:value-of select="//documentTitle"/> 
 
 <!-- Display Trial Court cause number and description -->

 <br/>
  <xsl:for-each select="relatedCase">
 	<xsl:if test="comment='Trial Court'">
	 	<xsl:value-of select="fullCaseNumber"/><br/> 
	</xsl:if>
<br/>

 <div align = "center">
 	<xsl:for-each select="court/judicialOfficer"> 
		<xsl:value-of select="fullName"/>,
 		&#xa0;<xsl:value-of select=".//roleName"/><br/> 
	</xsl:for-each> 
</div>
	
</xsl:for-each>
<P/>

<xsl:value-of select="../documentBody/paragraph[@type='Result Summary']"/>
____________________________________________________________________________________
<br/><br/>
<table width="80%">
<xsl:for-each select="//party/attorney"> 
  	<tr>
		<td width="60%" valign="top">
		<xsl:if test="not(personIdentification/comment)">
			&#xa0;&#xa0;&#xa0;&#xa0;<xsl:value-of select="fullName"/>
		</xsl:if>

		<xsl:if test="personIdentification/comment">
			<xsl:value-of select="fullName"/>,
			&#xa0;<xsl:value-of select="personIdentification/comment"/>
		</xsl:if>
		</td>
		<td width="40%" align="right">
		<xsl:if test="postalAddress/city">
  			<xsl:value-of select="postalAddress/city"/><br/>
		</xsl:if>
		<xsl:if test="not(personIdentification/comment)">
			&#xa0;&#xa0;<xsl:value-of select=".//roleName"/><p/>
		</xsl:if>
		</td> 
	</tr>
</xsl:for-each> 
</table>

____________________________________________________________________________________
 <p/>
 </div>
 
 </xsl:template> 
 
	<!-- 
#############################################################
-->
	
	<!-- This template displays the paragraphs in the body of the court 
document.  -->
	<xsl:template match = "documentBody">
		 <xsl:if test = "paragraphGroup">
			<xsl:for-each select = "paragraphGroup">
			<xsl:if test="paragraphGroupTitle | paragraphTitle">
				<hr/>
				<b><xsl:value-of select="paragraphGroupTitle | paragraphTitle"/></b><p/>
			</xsl:if>
				<xsl:choose>
					<xsl:when test = "paragraph">
							<xsl:apply-templates select="paragraph"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
		<xsl:value-of select="dateTimeSigned/date"/>
	</xsl:template>

	<!-- The following templates display the contents of elements within 
the <documentBody> element, including various <addIn> elements. -->

	<xsl:template match = "paragraphSubgroup1">
		<xsl:if test = "@title='Count'">
			<center>
				<xsl:value-of select = "@title"/>
				<xsl:if test = "@number">&#xa0;<xsl:value-of select = "@number"/>
					<p/>
				</xsl:if>
			</center>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "paragraph">
		<xsl:choose>
		<xsl:when test = "paragraphTitle">
			<center>
				<xsl:value-of select = "paragraphTitle"/>
				<xsl:if test = "@label">
					&#182;<xsl:value-of select = "@label"/>&#xa0;
				</xsl:if>
			</center>
			<xsl:apply-templates/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:if test = "@label">
				&#182;<xsl:value-of select = "@label"/>&#xa0;&#xa0;&#xa0;&#xa0;
			</xsl:if>
			<xsl:apply-templates />
		</xsl:otherwise>
		</xsl:choose>
		<br/>
		<br/>
	</xsl:template>

 	<xsl:template match="footnote"> 
		<span style="display:inline; font-size:8pt; font-weight:bold; vertical-align:super"> 
 			<a><xsl:attribute name="href">#<xsl:value-of select="footnoteNumber"/></xsl:attribute>
				<xsl:value-of select="footnoteNumber"/>
			</a>&#xa0;
		</span>
  	</xsl:template> 

	<xsl:template match = "addIn">
		<xsl:choose>
 		<xsl:when test="@addInType='quotationHeading'"> 
			<blockquote>
				<xsl:apply-templates/>
			</blockquote>
  		</xsl:when> 
		<xsl:when test="@addInType='quotationHeading'">
				<xsl:apply-templates/>&#xa0;
		</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="subparagraph1">
		<blockquote>
		<xsl:choose>
		<xsl:when test = "paragraphTitle">
			<center>
				<xsl:value-of select = "paragraphTitle"/>
				<xsl:if test = "@label">
					<xsl:value-of select = "@label"/>&#xa0;
				</xsl:if>
			</center>
			<xsl:apply-templates/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:if test = "@label">
				<xsl:value-of select = "@label"/>.&#xa0;&#xa0;&#xa0;&#xa0;
			</xsl:if>
			<xsl:apply-templates />
		</xsl:otherwise>
		</xsl:choose>
		</blockquote>
	</xsl:template>

	<xsl:template match = "simpleCite">
		<i>
			<xsl:apply-templates/>
		</i>
	</xsl:template>

	<xsl:template match = "keyword">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "phrase">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "literal">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "quotation">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "date[@dateType]">
		<b>
			<xsl:apply-templates/>
		</b>
	</xsl:template>

	<xsl:template match = "list">
		<xsl:for-each select = "listItem">
			<xsl:if test = "@title">
				<p/>
				<b><xsl:value-of select = "@title | @label"/>:</b>&#xa0;&#xa0;</xsl:if>
			<p/>
			<xsl:value-of select = "."/>
		</xsl:for-each>
		<xsl:if test = "list">
			<xsl:for-each select = "list">
				<p/>
				<xsl:if test = "@title or @type">
					<b>
						<xsl:value-of select = "@title"/>&#xa0;<xsl:value-of select = "@type"/>&#xa0;
						<xsl:value-of select = "@label"/>
					</b>
				</xsl:if>
				<table width = "50%">
					<xsl:for-each select = "listItem">
						<tr>
							<td width = "50%">&#xa0;&#xa0;
								<b>
									<xsl:value-of select = "@title"/>
								</b>
							</td>
							<td>
								<xsl:value-of select = "."/>
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>

 <!-- #################################################################  --> 
 
<!-- This template displays the contents of the <signers> 
 tag in the underlying XML document. --> 
 
 <xsl:template match="signers">
 
 <!-- This displays information regarding the signature line. --> 
 <p/>
 <table width="100%"> 
 
 <xsl:for-each select="signatory"> 
 	<tr>
 	<xsl:choose>
		<xsl:when test="contains(judicialOfficer[role/roleName],'Majority Author')">
 			<td width="50%"><td> 
 				<xsl:value-of select="signatureLine"/><br></br>
 				<xsl:value-of select="judicialOfficer/fullName"/>, 
				<xsl:value-of select="judicialOfficer//roleName"/> <br/><br/>
 			</td></td>
 		</xsl:when> 
		<xsl:when test="contains(judicialOfficer[role/roleName],'Concurring')">
    		<tr>
    		<td>
    		CONCURRING:<br/><br/>
    			<xsl:value-of select="signatureLine"/><br></br>
    			<xsl:value-of select="judicialOfficer/fullName"/>, 
				<xsl:value-of select="judicialOfficer//roleName"/> <br/><br/>
    		</td>
    		</tr>
        </xsl:when> 
    <xsl:otherwise>
    	<td width="50%"><td>
    		<xsl:value-of select="signatureLine"/><br></br> 
		 	<xsl:if test="attorney[fullName]"> 
 				<xsl:value-of select="attorney/fullName"/>, 
				<xsl:value-of select="attorney//roleName"/> <br/>
		  	</xsl:if> 
		</td></td>
	</xsl:otherwise>
    </xsl:choose>
	</tr> 

 </xsl:for-each> 

 </table> 
 </xsl:template> 
 </xsl:stylesheet> 


